==> v8.3.zip: ru_twords_ru_tw/bible/kt/unleavenedbread.md <==
# пресный хлеб, бездрожжевой хлеб, опреснок, опресноки

## Определение:

Пресный хлеб — это хлеб, который изготавливается без дрожжей или без закваски. Этот вид хлеба обычно плоский, потому что у него нет закваски.

* Он известен из ветхозаветной истории, когда Бог велел израильтянам бежать из Египта, не дождавшись, пока взойдёт их тесто. С тех пор евреи едят пресный хлеб во время ежегодного празднования Пасхи в память о том, как они поспешно уходили из Египта.
* Закваска иногда символизирует грех. Употребление пресного хлеба символизирует стремление избавиться от греха.

## Варианты перевода:

* Словосочетание “пресный хлеб” можно перевести как “хлеб без закваски” или “бездрожжевой хлеб”.
* Убедитесь, что перевод этого слова соответствует вашему переводу слов “закваска” и “дрожжи”.
* В некоторых контекстах словосочетание “пресный хлеб” употребляется, когда речь идёт о “Празднике опресноков” или “Празднике пресных хлебов”.

(См. также: [хлеб](../other/bread.md), [Египет](../names/egypt.md), [пир](../other/feast.md), [Пасха](../kt/passover.md), [слуга](../other/servant.md), [грех](../kt/sin.md), [закваска](../other/yeast.md))

## Ссылки на библейский текст:

* [1 Кор. 5:6-8](rc://*/tn/help/1co/05/06)
* [2 Пар. 30:13-15](rc://*/tn/help/2ch/30/13)
* [Деян. 12:3-4](rc://*/tn/help/act/12/03)
* [Исх. 23:14-15](rc://*/tn/help/exo/23/14)
* [Ezra 6:21-22](rc://*/tn/help/ezr/06/21)
* [Быт. 19:1-3](rc://*/tn/help/gen/19/01)
* [Judges 6:21](rc://*/tn/help/jdg/06/21)
* [Лев. 8:1-3](rc://*/tn/help/lev/08/01)
* [Лк. 22:1-2](rc://*/tn/help/luk/22/01)

## Данные о слове:

* Номера Стронга: H4682, G106

==> v9.2.zip: ru_twords_ru_tw/bible/kt/unleavenedbread.md <==
# пресный хлеб, бездрожжевой хлеб, опреснок, опресноки
## Определение:

Пресный хлеб — это хлеб, который изготавливается без дрожжей или без закваски. Этот вид хлеба обычно плоский, потому что у него нет закваски.
* Он известен из ветхозаветной истории, когда Бог велел израильтянам бежать из Египта, не дождавшись, пока взойдёт их тесто. С тех пор евреи едят пресный хлеб во время ежегодного празднования Пасхи в память о том, как они поспешно уходили из Египта.
* Закваска иногда символизирует грех. Употребление пресного хлеба символизирует стремление избавиться от греха.

## Варианты перевода:

* Словосочетание “пресный хлеб” можно перевести как “хлеб без закваски” или “бездрожжевой хлеб”.
* Убедитесь, что перевод этого слова соответствует вашему переводу слов “закваска” и “дрожжи”.
* В некоторых контекстах словосочетание “пресный хлеб” употребляется, когда речь идёт о “Празднике опресноков” или “Празднике пресных хлебов”. 

(См. также: [хлеб](../other/bread.md), [Египет](../names/egypt.md), [пир](../other/feast.md), [Пасха](../kt/passover.md), [слуга](../other/servant.md), [грех](../kt/sin.md), [закваска](../other/yeast.md))

## Ссылки на библейский текст:

* [1 Кор. 5:6-8](rc://ru/tn/help/1co/05/06)
* [2 Пар. 30:13-15](rc://ru/tn/help/2ch/30/13)
* [Деян. 12:3-4](rc://ru/tn/help/act/12/03)
* [Исх. 23:14-15](rc://ru/tn/help/exo/23/14)
* [Ezra 6:21-22](rc://ru/tn/help/ezr/06/21)
* [Быт. 19:1-3](rc://ru/tn/help/gen/19/01)
* [Judges 6:21](rc://ru/tn/help/jdg/06/21)
* [Лев. 8:1-3](rc://ru/tn/help/lev/08/01)
* [Лк. 22:1-2](rc://ru/tn/help/luk/22/01)

## Данные о слове:

* Номера Стронга: H4682, G106
